@@ -7,7 +7,7 @@ use SVG;
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = 0.35;
+our $VERSION = 0.36;
 
 # aliases to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
@@ -91,7 +91,8 @@ sub _make_mark
     return;
 }
 
-1; # Magic true value required at end of module
+1;
+
 __END__
 
 =head1 NAME
@@ -100,7 +101,7 @@ SVG::Sparkline::RangeArea - Supports SVG::Sparkline for range area graphs.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::RangeArea version 0.35
+This document describes SVG::Sparkline::RangeArea version 0.36
 
 =head1 DESCRIPTION
 
@@ -163,7 +164,7 @@ G. Wade Johnson  C<< wade@anomaly.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2012, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl 5.8.0. See L<perlartistic>.
