@@ -6,7 +6,7 @@ use Carp;
 use List::Util;
 use SVG;
 
-our $VERSION = 0.35;
+our $VERSION = 0.36;
 
 sub format_f
 {
@@ -216,7 +216,8 @@ sub mark_to_index
 }
 
 
-1; # Magic true value required at end of module
+1;
+
 __END__
 
 =head1 NAME
@@ -225,7 +226,7 @@ SVG::Sparkline::Utils - Utility functions used by the sparkline type modules.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::Utils version 0.35
+This document describes SVG::Sparkline::Utils version 0.36
 
 =head1 DESCRIPTION
 
@@ -324,7 +325,7 @@ G. Wade Johnson  C<< wade@anomaly.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2012, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl 5.8.0. See L<perlartistic>.
