@@ -7,7 +7,7 @@ use SVG;
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = 0.35;
+our $VERSION = 0.36;
 
 # alias to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
@@ -164,7 +164,8 @@ sub _consolidate_moves
     return ($x||$y) ? 'm' . _f($x).',' . _f($y) : '';
 }
 
-1; # Magic true value required at end of module
+1;
+
 __END__
 
 =head1 NAME
@@ -173,7 +174,7 @@ SVG::Sparkline::Whisker - Supports SVG::Sparkline for whisker graphs.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::Whisker version 0.35
+This document describes SVG::Sparkline::Whisker version 0.36
 
 =head1 DESCRIPTION
 
@@ -232,7 +233,7 @@ G. Wade Johnson  C<< wade@anomaly.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2009, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2012, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl 5.8.0. See L<perlartistic>.
